@@ -20,9 +20,9 @@ from .ruobr_api import (
     Ruobr,
     AsyncRuobr,
     AuthenticationException,
-    NoSuccessExceptionException,
+    NoSuccessException,
 )
 
 __author__ = "raitonoberu"
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 __email__ = "raitonoberu@mail.ru"
